@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1992, 1993, 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -535,7 +535,15 @@ cache_write_item(fp, key, cp)
 		return -1;
 	if (fwrite_sane(fp, &cp->st, sizeof(cp->st)))
 		return -1;
-	if (fwrite_sane(fp, &cp->ingredients.nstrings, sizeof(cp->ingredients.nstrings)))
+	if
+	(
+		fwrite_sane
+		(
+			fp,
+			&cp->ingredients.nstrings,
+			sizeof(cp->ingredients.nstrings)
+		)
+	)
 		return -1;
 	for (j = 0; j < cp->ingredients.nstrings; ++j)
 		if (cache_write_string(fp, cp->ingredients.string[j]))
