@@ -1,6 +1,6 @@
 /*
  *	cook - a program construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,4 +29,9 @@ void help _((char *, void (*)(void)));
 void generic_argument _((void(*)(void)));
 void bad_argument _((void(*)(void)));
 
+void arg_duplicate _((int, void(*)(void)));
+void arg_duplicate_cur _((void(*)(void)));
+void arg_needs_string _((int, void(*)(void)));
+void arg_needs_number _((int, void(*)(void)));
+
 #endif /* HELP_H */
