@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997-1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -926,7 +926,7 @@ ret:
 		 * The output files need to be at least this date
 		 * stamp to be mtime-consistent with the inputs.
 		 */
-		mtime = need_age + 1;
+		mtime = need_age + TIMESTAMP_GRANULARITY;
 
 		if (option_test(OPTION_FINGERPRINT))
 		{
@@ -1082,8 +1082,15 @@ ret:
 		 * Advance one second younger.  This is the youngest a
 		 * target may be to be mtime-consistent with the
 		 * ingredients.
+		 *
+		 * Actually, on Cygwin on FAT filesystems, the timestamp
+		 * granularity is 2 seconds.  There is no pathconf query
+		 * to tell you the time stamp granularity (sigh) so we
+		 * have to assume that if you are on Cygwin, you needd
+		 * a 2 second granularity, even if you are on an NTFS
+		 * file system with 1 second granularity.
 		 */
-		need_age_youngest++;
+		need_age_youngest += TIMESTAMP_GRANULARITY;
 
 		/*
 		 * check each of the targets for consistency
